@@ -4,26 +4,27 @@ Asynchronous rate limiting strategies
 
 import weakref
 from abc import ABC, abstractmethod
-from typing import cast
-from typing import Iterable, Tuple
+from typing import Iterable, Tuple, cast
 
 from ..limits import RateLimitItem
-from ..storage import StorageTypes
 from .storage import Storage
 
 
 class RateLimiter(ABC):
-    def __init__(self, storage: StorageTypes):
+    def __init__(self, storage: Storage):
         self.storage = weakref.ref(cast(Storage, storage))
 
     @abstractmethod
-    async def hit(self, item: RateLimitItem, *identifiers: Iterable[str]) -> bool:
+    async def hit(
+        self, item: RateLimitItem, *identifiers: Iterable[str], cost: int = 1
+    ) -> bool:
         """
         Consume the rate limit
 
         :param item: the rate limit item
         :param identifiers: variable list of strings to uniquely identify the
          limit
+        :param cost: The cost of this hit, default 1
         """
         raise NotImplementedError
 
@@ -61,7 +62,7 @@ class MovingWindowRateLimiter(RateLimiter):
     Reference: :ref:`strategies:moving window`
     """
 
-    def __init__(self, storage: StorageTypes) -> None:
+    def __init__(self, storage: Storage) -> None:
         if not (
             hasattr(storage, "acquire_entry") or hasattr(storage, "get_moving_window")
         ):
@@ -71,16 +72,18 @@ class MovingWindowRateLimiter(RateLimiter):
             )
         super().__init__(storage)
 
-    async def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    async def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: the rate limit item
         :param identifiers: variable list of strings to uniquely identify the
          limit
+        :param cost: The cost of this hit, default 1
         """
+
         return await self.storage().acquire_entry(  # type: ignore
-            item.key_for(*identifiers), item.amount, item.get_expiry()
+            item.key_for(*identifiers), item.amount, item.get_expiry(), amount=cost
         )
 
     async def test(self, item: RateLimitItem, *identifiers) -> bool:
@@ -95,6 +98,7 @@ class MovingWindowRateLimiter(RateLimiter):
             item.key_for(*identifiers), item.amount, item.get_expiry(),
         )
         amount = res[1]
+
         return amount < item.amount
 
     async def get_window_stats(
@@ -112,6 +116,7 @@ class MovingWindowRateLimiter(RateLimiter):
             item.key_for(*identifiers), item.amount, item.get_expiry()
         )
         reset = window_start + item.get_expiry()
+
         return (reset, item.amount - window_items)
 
 
@@ -120,16 +125,23 @@ class FixedWindowRateLimiter(RateLimiter):
     Reference: :ref:`strategies:fixed window`
     """
 
-    async def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    async def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: the rate limit item
         :param identifiers: variable list of strings to uniquely identify the
          limit
+        :param cost: The cost of this hit, default 1
         """
+
         return (
-            await self.storage().incr(item.key_for(*identifiers), item.get_expiry())
+            await self.storage().incr(
+                item.key_for(*identifiers),
+                item.get_expiry(),
+                elastic_expiry=False,
+                amount=cost,
+            )
             <= item.amount
         )
 
@@ -141,6 +153,7 @@ class FixedWindowRateLimiter(RateLimiter):
         :param identifiers: variable list of strings to uniquely identify the
          limit
         """
+
         return await self.storage().get(item.key_for(*identifiers)) < item.amount
 
     async def get_window_stats(
@@ -158,6 +171,7 @@ class FixedWindowRateLimiter(RateLimiter):
             0, item.amount - await self.storage().get(item.key_for(*identifiers)),
         )
         reset = await self.storage().get_expiry(item.key_for(*identifiers))
+
         return (reset, remaining)
 
 
@@ -166,17 +180,22 @@ class FixedWindowElasticExpiryRateLimiter(FixedWindowRateLimiter):
     Reference: :ref:`strategies:fixed window with elastic expiry`
     """
 
-    async def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    async def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: a :class:`limits.limits.RateLimitItem` instance
         :param identifiers: variable list of strings to uniquely identify the
          limit
+        :param cost: The cost of this hit, default 1
         """
         amount = await self.storage().incr(
-            item.key_for(*identifiers), item.get_expiry(), True
+            item.key_for(*identifiers),
+            item.get_expiry(),
+            elastic_expiry=True,
+            amount=cost,
         )
+
         return amount <= item.amount
 
 
