@@ -31,6 +31,7 @@ class MemcachedStorage(Storage):
         """
         parsed = urllib.parse.urlparse(uri)
         self.hosts = []
+
         for loc in parsed.netloc.strip().split(","):
             if not loc:
                 continue
@@ -38,6 +39,7 @@ class MemcachedStorage(Storage):
             self.hosts.append((host, int(port)))
         else:
             # filesystem path to UDS
+
             if parsed.path and not parsed.netloc and not parsed.port:
                 self.hosts = [parsed.path]  # type: ignore
 
@@ -61,6 +63,7 @@ class MemcachedStorage(Storage):
         :param module: the memcached module
         :param hosts: list of memcached hosts
         """
+
         return (
             module.HashClient(hosts, **kwargs)
             if len(hosts) > 1
@@ -70,8 +73,10 @@ class MemcachedStorage(Storage):
     def call_memcached_func(self, func, *args, **kwargs):
         if "noreply" in kwargs:
             argspec = inspect.getfullargspec(func)
+
             if not ("noreply" in argspec.args or argspec.varkw):
                 kwargs.pop("noreply")  # noqa
+
         return func(*args, **kwargs)
 
     @property
@@ -79,6 +84,7 @@ class MemcachedStorage(Storage):
         """
         lazily creates a memcached client instance using a thread local
         """
+
         if not (hasattr(self.local_storage, "storage") and self.local_storage.storage):
             self.local_storage.storage = self.client_getter(
                 get_dependency(
@@ -94,6 +100,7 @@ class MemcachedStorage(Storage):
         """
         :param key: the key to get the counter value for
         """
+
         return int(self.storage.get(key) or 0)
 
     def clear(self, key: str) -> None:
@@ -102,7 +109,7 @@ class MemcachedStorage(Storage):
         """
         self.storage.delete(key)
 
-    def incr(self, key: str, expiry: int, elastic_expiry=False) -> int:
+    def incr(self, key: str, expiry: int, elastic_expiry=False, amount: int = 1) -> int:
         """
         increments the counter for a given rate limit key
 
@@ -110,11 +117,14 @@ class MemcachedStorage(Storage):
         :param expiry: amount in seconds for the key to expire in
         :param elastic_expiry: whether to keep extending the rate limit
          window every hit.
+        :param amount: the number to increment by
         """
+
         if not self.call_memcached_func(
-            self.storage.add, key, 1, expiry, noreply=False
+            self.storage.add, key, amount, expiry, noreply=False
         ):
-            value = self.storage.incr(key, 1) or 1
+            value = self.storage.incr(key, amount) or amount
+
             if elastic_expiry:
                 self.call_memcached_func(self.storage.touch, key, expiry)
                 self.call_memcached_func(
@@ -124,6 +134,7 @@ class MemcachedStorage(Storage):
                     expire=expiry,
                     noreply=False,
                 )
+
             return value
         else:
             self.call_memcached_func(
@@ -133,12 +144,14 @@ class MemcachedStorage(Storage):
                 expire=expiry,
                 noreply=False,
             )
-        return 1
+
+        return amount
 
     def get_expiry(self, key: str) -> int:
         """
         :param key: the key to get the expiry for
         """
+
         return int(float(self.storage.get(key + "/expires") or time.time()))
 
     def check(self) -> bool:
@@ -148,6 +161,7 @@ class MemcachedStorage(Storage):
         """
         try:
             self.call_memcached_func(self.storage.get, "limiter-check")
+
             return True
         except:  # noqa
             return False
