@@ -4,27 +4,27 @@ Rate limiting strategies
 
 import weakref
 from abc import ABCMeta, abstractmethod
-from typing import cast
-from typing import Dict, Tuple, Type, Union
+from typing import Dict, Tuple, Type, Union, cast
 
 from .limits import RateLimitItem
-from .storage import Storage, StorageTypes
+from .storage import Storage
 
 
 class RateLimiter(metaclass=ABCMeta):
-    def __init__(self, storage: StorageTypes):
+    def __init__(self, storage: Storage):
         self.storage: weakref.ReferenceType[Storage] = weakref.ref(
             cast(Storage, storage)
         )
 
     @abstractmethod
-    def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: The rate limit item
         :param identifiers: variable list of strings to uniquely identify this
          instance of the limit
+        :param cost: The cost of this hit, default 1
         """
         raise NotImplementedError
 
@@ -60,7 +60,7 @@ class MovingWindowRateLimiter(RateLimiter):
     Reference: :ref:`strategies:moving window`
     """
 
-    def __init__(self, storage: StorageTypes):
+    def __init__(self, storage: Storage):
         if not (
             hasattr(storage, "acquire_entry") or hasattr(storage, "get_moving_window")
         ):
@@ -70,18 +70,19 @@ class MovingWindowRateLimiter(RateLimiter):
             )
         super().__init__(storage)
 
-    def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: The rate limit item
         :param identifiers: variable list of strings to uniquely identify this
          instance of the limit
+        :param cost: The cost of this hit, default 1
         :return: (reset time, remaining)
         """
 
         return self.storage().acquire_entry(  # type: ignore
-            item.key_for(*identifiers), item.amount, item.get_expiry()
+            item.key_for(*identifiers), item.amount, item.get_expiry(), amount=cost
         )
 
     def test(self, item: RateLimitItem, *identifiers) -> bool:
@@ -122,17 +123,23 @@ class FixedWindowRateLimiter(RateLimiter):
     Reference: :ref:`strategies:fixed window`
     """
 
-    def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: The rate limit item
         :param identifiers: variable list of strings to uniquely identify this
          instance of the limit
+        :param cost: The cost of this hit, default 1
         """
 
         return (
-            self.storage().incr(item.key_for(*identifiers), item.get_expiry())
+            self.storage().incr(
+                item.key_for(*identifiers),
+                item.get_expiry(),
+                elastic_expiry=False,
+                amount=cost,
+            )
             <= item.amount
         )
 
@@ -167,17 +174,23 @@ class FixedWindowElasticExpiryRateLimiter(FixedWindowRateLimiter):
     Reference: :ref:`strategies:fixed window with elastic expiry`
     """
 
-    def hit(self, item: RateLimitItem, *identifiers) -> bool:
+    def hit(self, item: RateLimitItem, *identifiers, cost: int = 1) -> bool:
         """
         Consume the rate limit
 
         :param item: The rate limit item
         :param identifiers: variable list of strings to uniquely identify this
          instance of the limit
+        :param cost: The cost of this hit, default 1
         """
 
         return (
-            self.storage().incr(item.key_for(*identifiers), item.get_expiry(), True)
+            self.storage().incr(
+                item.key_for(*identifiers),
+                item.get_expiry(),
+                elastic_expiry=True,
+                amount=cost,
+            )
             <= item.amount
         )
 
